%%
%% The official i6 slide template _class_
%% created by Philippe Dreuw and Thomas Deselaers, 2005
%%
%% $Id: i6beamerstyle.cls,v 1.12 2005/12/05 09:21:37 dreuw Exp $
%%
%% Possible options for:
%%  - language       : 'english' (default), 'german'
%%  - page numbering : 'nonumber', 'lastpage' to enable automatic page n/m numbering, 
%%                     'userlastpage' to enable a user defined page n/m numbering using \LastPage command,  
%%                      or leave empty for normal page numbering (default)
%%  - itemize        : 'triangle' or leave empty for bullets (default)
%%  - page titles    : 'allowpagebreaks' to enable titles with automatic page breaks, 
%%                     'nopagebreaks' to disable (default)
%%  - page layout    : 'vertical' to enable vertical centering on each slide using \vfill ... \vfill
%%
%% alternative:
%% \documentclass[a4paper, landscape]{article}\usepackage[english, userlastpage, triangle, allowpagebreaks]{i6beamerstyle}
%%
%% flyspell can read the local ispelldict variable to automatically change the dictionary, 
%% e.g. german-new8
%% Local IspellDict: american
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{i6beamerstyle}[2005/10/12]

%%% define if variables
\newif\if@english
\@englishtrue %% default language

\newif\if@ngerman
\@ngermanfalse

\newif\if@lastpage
\@lastpagefalse

\newif\if@center
\@centerfalse

\newcommand{\LastPageLabelSet}{0}
\newcommand{\NoNumber}{0}
\newcommand{\UseTriangle}{0}
\newcommand{\AllowPageBreaks}{0}

\DeclareOption{lastpage}{\@lastpagetrue\renewcommand{\LastPageLabelSet}{1}}
\DeclareOption{userlastpage}{\@lastpagefalse\renewcommand{\LastPageLabelSet}{1}}
\DeclareOption{nonumber}{\renewcommand{\NoNumber}{1}}
\DeclareOption{triangle}{\renewcommand{\UseTriangle}{1}}
\DeclareOption{allowpagebreaks}{\renewcommand{\AllowPageBreaks}{1}}
\DeclareOption{nopagebreaks}{\renewcommand{\AllowPageBreaks}{0}}
\DeclareOption{vertical}{\@centertrue}
\DeclareOption{german}{%
  \PassOptionsToPackage{ngerman}{babel}%
  \@ngermantrue\@englishfalse%
}
\DeclareOption{english}{%
  \PassOptionsToPackage{\CurrentOption}{babel}%
  \@englishtrue\@ngermanfalse%
}
\DeclareOption{a4paper}{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{landscape}{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{11pt}{\PassOptionsToClass{\CurrentOption}{article}}
%\DeclareOption*{\typeout{Warning -- Unknown Option: \CurrentOption}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ExecuteOptions{a4paper}
\ExecuteOptions{landscape}
\ExecuteOptions{11pt}
\ExecuteOptions{english}   
\ExecuteOptions{nopagebreaks}
\ProcessOptions\relax
\LoadClass{article}

\RequirePackage{babel}
\newcommand{\thankyou}{thankyou}
\if@english
  \addto\captionsenglish{%
    \renewcommand{\contentsname}{Outline}%
    \renewcommand{\figurename}{Fig.}%
    \renewcommand{\tablename}{Tab.}%
    \renewcommand{\thankyou}{Thank you for your attention}
  }
\else
  \if@ngerman
    \addto\captionsngerman{%
      \renewcommand{\contentsname}{bersicht}%
      \renewcommand{\figurename}{Abb.}%
      \renewcommand{\tablename}{Tab.}%
      \renewcommand{\thankyou}{Danke fr Ihre Aufmerksamkeit}
    }
  \fi
\fi

\if@lastpage
  \RequirePackage{lastpage}
\fi


\newcommand{\verticalcenter}{}%
\if@center
  %%\renewcommand{\verticalcenter}{\phantom{x}\vspace{-\baselineskip}}%
  \renewcommand{\verticalcenter}{\rule{0pt}{0pt}}%
\fi

% layout %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\special{papersize=297mm,210mm} % dvips ignoriert die Einstellung landscape
\usepackage[hmargin=5mm,nohead,foot=7mm,top=5mm]{geometry}
\usepackage{fancyheadings}
\usepackage{ifthen}
\usepackage{minitoc}

% tables %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage{longtable}
\usepackage{ragged2e}             % Flattersatz mit Trennung
\usepackage{rotating}
\usepackage{tabularx}
\usepackage{booktabs, array}      % Zustzliche horizontale Linien mit passenden Abstnden
\usepackage{dcolumn}              % Zahlen erst am Dezimalpunkt ausrichten, dann linksbuendig
\usepackage{colortbl}

\makeatletter 
\newcolumntype{D}[1]{>{\DC@{.}{.}{#1}}l<{\DC@end}}              % write {.}{,} instead of {.}{.} if you want to substitute the '.' by a ',' -- used for results
\newcolumntype{E}[1]{>{\scriptsize\DC@{.}{.}{#1}}l<{\DC@end}}   % write {.}{,} instead of {.}{.} if you want to substitute the '.' by a ',' -- like D but in scriptsize
                                                                % this can be used for values or parameters, not for results
\makeatother

%\newcolumntype{N}{>{\scriptsize}l}                               % etwas kleinerer Kopf als normal
\newcolumntype{N}{>{\normalsize}l}                                %  normaler Kopf
%\newcolumntype{V}[1]{>{\scriptsize\RaggedRight\hspace{0pt}}p{#1}} % Flattersatz angegebener Breite; Trennung auch im ersten Wort mglich 
\newcolumntype{V}[1]{>{\normalsize\RaggedRight\hspace{0pt}}p{#1}} % Flattersatz angegebener Breite; Trennung auch im ersten Wort mglich 
%\newcolumntype{R}[1]{>{\begin{turn}{90}\begin{minipage}{#1}\scriptsize\RaggedRight\hspace{0pt}}l<{\end{minipage}\end{turn}}}  % Spaltenkopf um 90 gedreht
\newcolumntype{R}[1]{>{\begin{turn}{90}\begin{minipage}{#1}\normalsize\RaggedRight\hspace{0pt}}l<{\end{minipage}\end{turn}}}  % Spaltenkopf um 90 gedreht

                                                                  % columntype X = p{...}, also raggedright
\newcolumntype{Y}{>{\raggedleft\arraybackslash}X}                 % tabularx Spalten rechtsbndig ausrichten
\newcolumntype{Z}{>{\centering\arraybackslash}X}                  % tabularx Spalten zentrieren


% fonts %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage[latin1]{inputenc}
\usepackage[T1]{fontenc}
\usepackage{times}
\renewcommand{\familydefault}{\sfdefault}
\usepackage{amsmath,amsthm, amssymb, latexsym}
\boldmath\bfseries

% color %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage{xcolor}
\definecolor{i6blue}{cmyk}{1,0.305,0,0.06}
\definecolor{i6bluedark}{rgb}{0.0156,0.2578,0.5625} 

\def\isechsblue#1    {\textcolor{i6blue} {#1} }
\def\isechsbluedark#1    {\textcolor{i6bluedark} {#1} }
\def\blue#1    {\textcolor{blue} {#1} }
\def\red#1     {\textcolor{red} {#1} }
\def\green#1   {\textcolor{green} {#1} }
\def\magenta#1 {\textcolor{magenta} {#1} }


% list and enumerate %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage{paralist}
\ifthenelse{\equal{\UseTriangle}{1}}{%
  \setdefaultitem{\textcolor{i6bluedark}{$\blacktriangleright$}}{\textcolor{i6bluedark}{$\triangleright$}}{$\circ$}{}
}{%
  \setdefaultitem{\textbullet}{\normalfont\bfseries \textendash}{\textasteriskcentered}{\textperiodcentered}   %% LaTeX default
}


% math operators and symbols %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\argmin}{\operatornamewithlimits{argmin}}
\newcommand{\argmax}{\operatornamewithlimits{argmax}}
\newcommand{\real}{\mathbb{R}}


% graphic %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage{ifpdf}
\usepackage{epsf}
\usepackage{graphicx}

% check for PDFLaTeX or LaTeX
\newif\ifpdf
\ifx\pdfoutput\undefined
  \pdffalse % we are not running PDFLaTeX
\else
  \pdfoutput=1 % we are running PDFLaTeX
  \pdftrue
\fi

%%%%%% Insert xfig images in pdftex manner
%% this macro needs only the file path
\newcommand{\inputfigure}[1]{%
  \ifpdf%
    \input{#1.pdf_t}%
  \else%
    \input{#1.pstex_t}%
  \fi
}

%%%%%% Insert xfig images in pdftex manner
%% this macro needs three parameters:
%%  1: desired image width, 2: desired image height
%%    (! in one of those keeps aspect ratio
%%  3: the name of the tex file which includes the image and writes the text
\newcommand{\inputfigurex}[3]{%
  \ifpdf%
    \resizebox{#1}{#2}{\input{#3.pdf_t}}%
  \else%
    \resizebox{#1}{#2}{\input{#3.pstex_t}}%
  \fi
}



% directories  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\imagedir}{./images/}
\newcommand{\imagetemplatedir}{/u/figures/}
\newcommand{\figurepath}{/u/figures/}
\newcommand{\xfigdir}{./xfigures/}
\newcommand{\logodir}{./logos/}
\newcommand{\audiodir}{./audio/}
\newcommand{\videodir}{./video/}
\newcommand{\sourcedir}{./sources/}

\graphicspath{\imagedir, \xfigdir, \imagetemplatedir, \figurepath}



% hyperref %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage[setpagesize=false,
    pagebackref,
    pdfstartview=Fit,
    colorlinks,           % Text als Link anstatt Box
    linkcolor=i6bluedark, % Linkfarbe, std=red
    urlcolor=i6bluedark,  % URL Linkfarbe, std=blue
    filecolor=i6bluedark, % Color for URLs which open local files
    citecolor=black,      % cite Linkfarbe, std=green
    pagecolor=black,      % Color for links to other pages, std=red
    menucolor=black,      % Color for Acrobat menu items, std=red
    breaklinks,           % Links ber mehrere Zeilen mglich
    bookmarks,            % Acrobat Bookmarks erstellen
    bookmarksopen=true,   % Acrobat Bookmarks beim ffnen des Dokumentes anzeigen
]{hyperref}


% caption und subfig options %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage[
  font={small, bf},           % small and bold font
  labelsep=none, 
  labelformat=empty,          % empty caption counter, only user label
  justification=centering,    % Each line of the caption will be centered.
  %justification=raggedright, % Each line of the caption will be moved to the left margin.
  %indention=-1cm,            % 
  aboveskip=1pt,
  belowskip=0pt,
  ]{caption}

\captionsetup[figure]{%
  position=below,
  aboveskip=1pt,
  belowskip=0pt,
}

\captionsetup[table]{%
  position=above
}

% define icons and logos
\newcommand{\soundicon}{\includegraphics[height=\baselineskip]{\logodir sound} \space}
\newcommand{\videoicon}{\includegraphics[height=\baselineskip]{\logodir video} \space}
\newcommand{\cdicon}{\includegraphics[height=\baselineskip]{\logodir cd} \space}
\newcommand{\dvdicon}{\includegraphics[height=\baselineskip]{\logodir dvd} \space}
\newcommand{\wwwicon}{\includegraphics[height=\baselineskip]{\logodir www} \space}

\newcommand{\isechsicon}{\includegraphics[height=\baselineskip]{logos/i6-hks44}}


\newcommand{\topleftlogo}{}
\newcommand{\toprightlogo}{\href{http://www.rwth-aachen.de/}{\includegraphics[height=6mm]{\logodir rwth-hks44}}}
\newcommand{\bottomleftlogo}{}
\newcommand{\bottomrightlogo}{\href{http://www-i6.informatik.rwth-aachen.de/}{\includegraphics[height=12mm]{\logodir i6-hks44}}}


% additional multimedia commands %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\audiofilelogobox}[1]{\href{run:\audiodir/#1}{\fbox{\soundicon \texttt{#1}}}}
\newcommand{\audiofilebox}[1]{\href{run:\audiodir/#1}{\fbox{\texttt{#1}}}}
\newcommand{\audiofilelogo}[1]{\href{run:\audiodir/#1}{\soundicon \texttt{#1}}}
\newcommand{\audiofiletext}[2]{\href{run:\audiodir/#1}{#2}}
\newcommand{\audiofile}[1]{\href{run:\audiodir/#1}{\texttt{#1}}}

\newcommand{\videofilethumbnailbox}[3]{\href{run:\videodir/#1}{\fbox{\includegraphics[#2]{#3}}}}
\newcommand{\videofilethumbnail}[3]{\href{run:\videodir/#1}{\includegraphics[#2]{#3}}}
\newcommand{\videofilelogobox}[1]{\href{run:\videodir/#1}{\fbox{\videoicon \texttt{#1}}}}
\newcommand{\videofilebox}[1]{\href{run:\videodir/#1}{\fbox{\texttt{#1}}}}
\newcommand{\videofilelogo}[1]{\href{run:\videodir/#1}{\videoicon \texttt{#1}}}
\newcommand{\videofiletext}[2]{\href{run:\videodir/#1}{#2}}
\newcommand{\videofile}[1]{\href{run:\videodir/#1}{\texttt{#1}}}
\newcommand{\videologo}[1]{\href{run:\videodir/#1}{\videoicon}}

\newcommand{\sourcefile}[1]{\href{file:\sourcedir/#1}{\fbox{show source \texttt{#1}}}}

\newcommand{\urllogobox}[1]{\fbox{\wwwicon \url{#1}}}
\newcommand{\urllogo}[1]{\wwwicon \url{#1}}


% @ environment %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\makeatletter
\renewcommand{\fps@figure}{htbp} % zustzliche option h fr figure und table kann hier zentral gesetzt werden
\renewcommand{\fps@table}{htbp}

\newcommand\@xii@ipt{12.1}
\newcommand\@xiv@vpt{14.5}
\newcommand\@xvii@iiipt{17.38}
\newcommand\@xxxpt{29.86}
\newcommand\@xxxvipt{35.83}
\newcommand\@xliiipt{43}
\newcommand\@lipt{51.60}
\renewcommand\normalsize{%
  \@setfontsize\normalsize\@xxpt\@xxvpt
  \abovedisplayskip 30\p@ \@plus3\p@ \@minus9\p@
  \abovedisplayshortskip \z@ \@plus3\p@
  \belowdisplayshortskip 7\p@ \@plus3\p@ \@minus4\p@
  \belowdisplayskip \abovedisplayskip}
\renewcommand\small{%
  \@setfontsize\small\@xviipt{22}%
  \abovedisplayskip 20\p@ \@plus3\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus2\p@
  \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
  \belowdisplayskip \abovedisplayskip}
\let\oldfootnotesize=\footnotesize
\renewcommand\footnotesize{%
  \@setfontsize\footnotesize\@xivpt{18}%
  \abovedisplayskip 16\p@ \@plus2\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus1\p@
  \belowdisplayshortskip 3\p@ \@plus1\p@ \@minus2\p@
  \belowdisplayskip \abovedisplayskip}
\renewcommand\scriptsize{\@setfontsize\scriptsize\@xiipt{15}}
\let\tiny=\scriptsize
\renewcommand\large{\@setfontsize\large\@xxvpt{32}}
\renewcommand\Large{\@setfontsize\Large\@xxxpt{38}}
\renewcommand\LARGE{\@setfontsize\LARGE\@xxxvipt{45}}
\renewcommand\huge{\@setfontsize\huge\@xliiipt{54}}
\let\Huge=\huge
\renewcommand\@pnumwidth{1.75em}
\newcommand\@secalign{\centering}
\newcommand\@subsecalign{\centering}
\newcommand\@subsubsecalign{\centering}
\newcommand\@paralign{\centering}
\newcommand\@subparalign{\centering}
\newcommand{\sectionalign}[1]{\renewcommand{\@secalign}{#1}}
\newcommand{\subsectionalign}[1]{\renewcommand{\@subsecalign}{#1}}
\newcommand{\subsubsectionalign}[1]{\renewcommand{\@subsubsecalign}{#1}}
\newcommand{\paragraphalign}[1]{\renewcommand{\@paralign}{#1}}
\newcommand{\subparagraphalign}[1]{\renewcommand{\@subparalign}{#1}}
\newcommand\@secsize{\Large}
\newcommand\@subsecsize{\large}
\newcommand\@subsubsecsize{\normalsize}
\newcommand\@parsize{\normalsize}
\newcommand\@subparsize{\normalsize}
\newcommand{\sectionsize}[1]{\renewcommand{\@secsize}{#1}}
\newcommand{\subsectionsize}[1]{\renewcommand{\@subsecsize}{#1}}
\newcommand{\subsubsectionsize}[1]{\renewcommand{\@subsubsecsize}{#1}}
\newcommand{\paragraphsize}[1]{\renewcommand{\@parsize}{#1}}
\newcommand{\subparagraphsize}[1]{\renewcommand{\@subparsize}{#1}}
\renewcommand\section{\thispagestyle{plain}\@startsection {section}{1}{\z@}%
 {-3.5ex \@plus -1ex \@minus -.2ex}%
 {2.3ex \@plus.2ex}%
 {\normalfont\@secsize\@secalign\bfseries}}
\renewcommand\subsection{\thispagestyle{plain}\@startsection{subsection}{2}{\z@}%
 {-3.25ex\@plus -1ex \@minus -.2ex}%
 {1.5ex \@plus .2ex}%
 {\normalfont\@subsecsize\@subsecalign\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
 {-3.25ex\@plus -1ex \@minus -.2ex}%
 {1.5ex \@plus .2ex}%
 {\normalfont\@subsubsecsize\@subsubsecalign\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
 {3.25ex \@plus1ex \@minus.2ex}%
 {-1em}%
 {\normalfont\@parsize\@paralign\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
 {3.25ex \@plus1ex \@minus .2ex}%
 {-1em}%
 {\normalfont\@subparsize\@subparalign\bfseries}}
\setlength\parindent{0\p@}
\makeatother

% Eliminate LaTeX warnings on screen (but put them in the log file):
\let\GenericWarning\GenericInfo
% Eliminate warnings about overfull boxes:
\hfuzz=\maxdimen \vfuzz=\maxdimen
\newdimen\hfuzz  \let\vfuzz=\hfuzz % prevent resetting by \slopp
% Eliminate warnings about underfull boxes:
\hbadness=10000    \vbadness=10000
\newcount\hbadness \let\vbadness=\hbadness

\newcommand{\csection}{\section}
\newcommand{\csubsection}{\subsection}
\newcommand{\csubsubsection}{\subsubsection}
\newcommand{\cparagraph}{\paragraph}
\newcommand{\csubparagraph}{\subparagraph}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Page settings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setcounter{secnumdepth}{2}
\setlength{\textwidth}     {274mm}     % {280mm}
\addtolength{\oddsidemargin} {+6mm}    % {+3mm}
\ifthenelse{\equal{\AllowPageBreaks}{1}}{%
  \setlength{\textheight}    {183mm}
  \addtolength{\headheight}  {10mm}      %15
  \addtolength{\headsep}     {3mm}       %15
}{%
  \setlength{\textheight}    {193mm}
  \addtolength{\headsep}     {3mm}       %15
}
%\addtolength{\topmargin}   {-5mm}
\pagestyle{fancyplain}

%%% define the plain page layout for fancy %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\sectionmark}[1]{\markboth{\thesection \space #1}{\thesection \space #1}}
\renewcommand{\subsectionmark}[1]{\markright{\thesubsection \space #1}}

\newcommand{\mymarks}{
  \ifthenelse{\equal{\leftmark}{\rightmark}}
  {\leftmark} % if equal
  {\rightmark}} % if not equal

%  {\rightmark} % if equal
%  {\leftmark \space -- \space \rightmark}} % if not equal


%%% define the layout for the head %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\headrulewidth}{0.0pt}
\lhead{\raisebox{0mm}[0mm][0mm]{\topleftlogo}}
\ifthenelse{\equal{\AllowPageBreaks}{1}}{%
  \chead{\nouppercase{\bfseries \large \mymarks}}
}{%
  \chead{} % empty head, has to be set manually by headline command
}
\rhead{\raisebox{0mm}[0mm][0mm]{\toprightlogo}}


%%% define the layout for the foot %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\footrulewidth}{0.4pt}
\renewcommand{\plainfootrulewidth}{0.4pt}

%%% change left-text of footline
\lfoot{\fancyplain{}\oldfootnotesize\vspace{-8mm} \authorshort: \titleshort}

%%% change center-text of footline - pagenumber with acrobat page function %%%%%%
\cfoot{\fancyplain{}{\oldfootnotesize\vspace{-5mm}%
    \ifthenelse{\equal{\NoNumber}{1}}{}{%
      \vspace{-0.3cm}\Acrobatmenu{GoToPage}{\textsf{\thepage}%
        \ifthenelse{\equal{\LastPageLabelSet}{1}}{\space/\space\pageref*{LastPage}}{%
        }
      }
    }
  }
}

%%% change right-text of footline
\rfoot{\fancyplain{}\oldfootnotesize\vspace{-8mm}\occasionshort { } \date \hspace*{0.3cm} \raisebox{0mm}[0mm][0mm]{\bottomrightlogo}}


%%% changing the length of the rule above the footline %%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\footrule}{\vbox to 0pt{\hbox to 262mm{\hrulefill}\vss}}
\bf

\fancypagestyle{plain}{%
  \lhead{\raisebox{0mm}[0mm][0mm]{\topleftlogo}}
  \chead{}
  \rhead{\raisebox{0mm}[0mm][0mm]{\toprightlogo}}
}

%%% define complete page layouts %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%
%% \phantom{x} is used here to allow a vertical centering
%% might be a problem for old lecture slides
%%
\newcommand{\NewPage}{\clearpage\newpage\verticalcenter}
%%\newcommand{\NewPage}{\clearpage\newpage}

\ifthenelse{\equal{\AllowPageBreaks}{1}}{%
  \newcommand{\headline}[1]{\pdfbookmark{#1}{\thepage}\markboth{#1}{#1}}
}{%
  \newcommand{\headline}[1]{\pdfbookmark{#1}{\thepage}\centerline{\large #1}\vspace{+0.8cm}}
}

\renewcommand{\title}{Title}                     % main title of the work (used for \TitlePage)
\newcommand{\titleshort}{titleshort}             % main title of the work (used for \lfoot)
\newcommand{\occasion}{occasion}                 % occasion (used for \TitlePage) 
\newcommand{\occasionshort}{occasion short}      % occasion short (used for \rfoot)
\renewcommand{\author}{author}                   % all the authors of the work (used for \TitlePage)      
\newcommand{\authorshort}{authorshort}           % author short (used for \lfoot)
\newcommand{\mainauthor}{mainauthor}             % the authors who presented the work (used for \FinalPage)
\newcommand{\email}{email}                       % all the emails of the work (used for \TitlePage)
\newcommand{\mainauthoremail}{mainauthoremail}   % presenter mail address(es) (used for \FinalPage)
\newcommand{\www}{www}                           % web address (used for \TitlePage _and_ \FinalPage)
\newcommand{\alert}[1]{\color{i6bluedark}{#1}\space\color{black}}

% predefined pages -- the title page
\newcommand{\TitlePage}{
  \vspace*{\fill}
  \bf
  \begin{center}
  \Large{\alert{\title}}\\[2ex]
  \large
  \author\\
  \normalsize
  \url{\email}\\[2ex]
  \occasion\space -- \date\\[3ex]
  
  Human Language Technology and Pattern Recognition \\
  Lehrstuhl f{\"u}r Informatik VI \\
  Computer Science Department \\
  RWTH Aachen University, Germany\\
  \end{center}
  \vspace*{\fill}
}

% predefined pages -- the empty last page, useful for correct page numbering 
\newcommand{\LastPage}{
  \NewPage%
  \markboth{}{}
  \label{LastPage}%
  \pdfbookmark{LastPage}{\thepage}%
}

% predefined pages -- the last page, with a short thankyou msg and necessary information of the mainauthor
\newcommand{\FinalPage}{
  \LastPage
  \vspace*{\fill}
  \bf
  \begin{center}
  \Large{\alert{\thankyou}}\\[2ex]
  \large
  \mainauthor\\[4ex]
  \normalsize
  \url{\mainauthoremail}\\[2ex]
  \url{\www}\\[2ex]
  \end{center}
  \vspace*{\fill}
}
